==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/plugins/GUITestBase/src/tests/common_scenarios/annotations/GTTestsCreateAnnotationWidget.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GT_TESTS_CREATE_ANNOTATION_WIDGET_H_
#define _U2_GT_TESTS_CREATE_ANNOTATION_WIDGET_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_create_annotation_widget {

#undef GUI_TEST_PREFIX
#define GUI_TEST_PREFIX "GUITest_common_scenarios_create_annotation_widget_"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0018)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022)
GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0024)
GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0026)
GUI_TEST_CLASS_DECLARATION(test_0027)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0032)
GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0039)
GUI_TEST_CLASS_DECLARATION(test_0040)
GUI_TEST_CLASS_DECLARATION(test_0041)
GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0043)

#undef GUI_TEST_PREFIX

}   // namespace GUITest_common_scenarios_create_annotation_widget

}   // namespace U2

#endif // _U2_GT_TESTS_CREATE_ANNOTATION_WIDGET_H_

==> ugene_1.20.0%2Bdfsg.orig.tar.xz: ugene-1.20.0/src/plugins/GUITestBase/src/tests/common_scenarios/annotations/GTTestsCreateAnnotationWidget.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GT_TESTS_CREATE_ANNOTATION_WIDGET_H_
#define _U2_GT_TESTS_CREATE_ANNOTATION_WIDGET_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_create_annotation_widget {

#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_create_annotation_widget"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0008)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0011)
GUI_TEST_CLASS_DECLARATION(test_0012)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0014)
GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0017)
GUI_TEST_CLASS_DECLARATION(test_0018)
GUI_TEST_CLASS_DECLARATION(test_0019)
GUI_TEST_CLASS_DECLARATION(test_0020)
GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022)
GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0024)
GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0026)
GUI_TEST_CLASS_DECLARATION(test_0027)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0032)
GUI_TEST_CLASS_DECLARATION(test_0033)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0039)
GUI_TEST_CLASS_DECLARATION(test_0040)
GUI_TEST_CLASS_DECLARATION(test_0041)
GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0043)

#undef GUI_TEST_SUITE

}   // namespace GUITest_common_scenarios_create_annotation_widget

}   // namespace U2

#endif // _U2_GT_TESTS_CREATE_ANNOTATION_WIDGET_H_
